@@ -3,6 +3,7 @@
 # Max-age cache
 # Remove dateutil/req from pagegetter
 # Make aws_sdb_reservation_domain optional
+# Make aws cache bucket optional
 
 from twisted.python.failure import Failure
 
@@ -130,6 +131,9 @@ class AWSpider:
             max_simultaneous_requests_per_domain=int(max_simultaneous_requests_per_domain)
         )
         
+        self.rq.setHostMaxRequestsPerSecond("127.0.0.1", 0)
+        self.rq.setHostMaxSimultaneousRequests("127.0.0.1", 0)
+        
         self.aws_access_key_id = aws_access_key_id
         self.aws_secret_access_key = aws_secret_access_key
         self.aws_s3_cache_bucket = aws_s3_cache_bucket
@@ -202,13 +206,21 @@ class AWSpider:
         
         running_time = time.time() - self.start_time
         cost = (self.sdb.box_usage * .14) * (60*60*24*30.4) / (running_time)
+        active_requests_by_host = self.rq.active_requests
+        pending_requests_by_host = dict( map(lambda x:(x[0], len(x[1])), self.rq.pending_requests.items() ) )
         
         data = {
             "paused":self.paused,
             "running_time":running_time,
-            "cost":cost
+            "cost":cost,
+            "active_requests_by_host":active_requests_by_host,
+            "pending_requests_by_host":pending_requests_by_host,
+            "active_requests":self.active,
+            "pending_requests":self.pending
         }
         
+        
+        
         logger.debug("Got server data:\n%s" % PrettyPrinter.pformat(data) )
 
         return data
@@ -375,7 +387,7 @@ class AWSpider:
             return self._callExposedFunctionImmediatelyCallback( d, function_name )
         
     def _callExposedFunctionImmediatelyCallback( self, data, function_name ):
-        logger.info("Function %s returned successfully:%s" % (function_name, data) )
+        logger.debug("Function %s returned successfully." % (function_name) )
         return data
         
     def _callExposedFunctionImmediatelyErrback( self, error, function_name ):
@@ -387,7 +399,7 @@ class AWSpider:
         return self.makeCallable( expose=True, *args, **kwargs )
         
     def makeCallable( self, func, interval=0, name=None, expose=False ):
-            
+        
         argspec = inspect.getargspec( func )
         arguments = argspec[0]
         if len(arguments) > 0 and arguments[0:1][0] == 'self':
@@ -421,6 +433,9 @@ class AWSpider:
                 logger.error( message )
                 raise Exception( message )
         
+        if function_name in self.functions:
+            raise Exception("A method or function with the name %s is already callable." % function_name)
+        
         self.functions[ function_name ] = {
             "function":func,
             "interval":interval,
